@@ -15,23 +15,23 @@
 #include <mapidefs.h>
 #include <kopano/ECKeyTable.h>
 #include <kopano/ECUnknown.h>
+#include <kopano/memory.hpp>
 #include <kopano/ustringutil.h>
 #include <kopano/Util.h>
 
 namespace KC {
 
 struct ECTableEntry {
-	LPSPropValue	lpsPropVal;
+	memory_ptr<SPropValue> lpsPropVal, lpsID;
 	BOOL			fDeleted;
 	BOOL			fDirty;
 	BOOL			fNew;
-	LPSPropValue	lpsID;
 	ULONG			cValues;
 };
 
 struct ECMEMADVISE {
 	ULONG				ulEventMask;
-	LPMAPIADVISESINK	lpAdviseSink;
+	object_ptr<IMAPIAdviseSink> lpAdviseSink;
 	//ULONG				ulConnection;
 };
 
@@ -80,15 +80,15 @@ protected:
 	// Data
 	std::map<unsigned int, ECTableEntry>	mapRows;
 	std::vector<ECMemTableView *>			lstViews;
-	LPSPropTagArray							lpsColumns;
 	ULONG									ulRowPropTag;
+	std::unique_ptr<SPropTagArray> lpsColumns;
 	std::recursive_mutex m_hDataMutex;
 
 	friend class ECMemTableView;
 	ALLOC_WRAP_FRIEND;
 };
 
-class _kc_export ECMemTableView _kc_final :
+class _kc_export ECMemTableView KC_FINAL_OPG :
     public ECUnknown, public IMAPITable {
 protected:
 	_kc_hidden ECMemTableView(ECMemTable *, const ECLocale &, ULONG flags);
@@ -129,13 +129,13 @@ private:
 	_kc_hidden HRESULT Notify(ULONG table_event, sObjectTableKey *row_item, sObjectTableKey *prev_row);
 
 	ECKeyTable lpKeyTable;
-	SSortOrderSet *lpsSortOrderSet = nullptr;
-	LPSPropTagArray			lpsPropTags;		// Columns
-	SRestriction *lpsRestriction = nullptr;
 	ECMemTable *			lpMemTable;
 	ECMapMemAdvise			m_mapAdvise;
-	ULONG m_ulConnection = 1; // Next advise id
+	std::unique_ptr<SSortOrderSet> lpsSortOrderSet;
+	std::unique_ptr<SPropTagArray> lpsPropTags; /* columns */
+	memory_ptr<SRestriction> lpsRestriction;
 	ECLocale				m_locale;
+	ULONG m_ulConnection = 1; // Next advise id
 	ULONG					m_ulFlags;
 
 	_kc_hidden virtual HRESULT UpdateSortOrRestrict(void);
