@@ -30,7 +30,7 @@ extern _kc_export int unix_create_pidfile(const char *argv0, ECConfig *, bool fo
 extern _kc_export int unix_daemonize(ECConfig *);
 extern _kc_export int unix_fork_function(void *(*)(void *), void *param, int nfds, int *closefds);
 extern _kc_export bool unix_system(const char *logname, const std::vector<std::string> &cmd, const char **env);
-extern _kc_export int ec_reexec(char **);
+extern _kc_export int ec_reexec(const char *const *);
 
 } /* namespace */
 
