@@ -9,7 +9,6 @@
 #include <edkmdb.h>		// LPREADSTATE
 #include <kopano/ECDefs.h>	// ECUSER
 using namespace KC;
-typedef ECUSERCLIENTUPDATESTATUS *LPECUSERCLIENTUPDATESTATUS;
 typedef ECSVRNAMELIST *LPECSVRNAMELIST;
 typedef ECSERVERLIST *LPECSERVERLIST;
 typedef ECQUOTASTATUS *LPECQUOTASTATUS;
@@ -29,7 +28,6 @@ PyObject *		Object_from_FILETIME(FILETIME ft);
 extern SPropValue *Object_to_p_SPropValue(PyObject *, ULONG flags = CONV_COPY_SHALLOW, void *base = nullptr);
 extern SPropValue *Object_to_LPSPropValue(PyObject *, ULONG flags = CONV_COPY_SHALLOW, void *base = nullptr);
 extern int Object_is_SPropValue(PyObject *);
-extern int Object_is_LPSPropValue(PyObject *);
 extern PyObject *List_from_SPropValue(const SPropValue *, ULONG n);
 extern PyObject *List_from_LPSPropValue(const SPropValue *, ULONG n);
 extern SPropValue *List_to_p_SPropValue(PyObject *, ULONG *nvals, ULONG flags = CONV_COPY_SHALLOW, void *base = nullptr);
@@ -107,9 +105,6 @@ ECQUOTA *Object_to_LPECQUOTA(PyObject *);
 PyObject *Object_from_LPECQUOTA(ECQUOTA *lpQuota);
 
 PyObject *Object_from_LPECQUOTASTATUS(ECQUOTASTATUS *lpQuotaStatus);
-
-PyObject *Object_from_LPECUSERCLIENTUPDATESTATUS(ECUSERCLIENTUPDATESTATUS *lpECUCUS);
-
 LPROWLIST		List_to_LPROWLIST(PyObject *, ULONG ulFlags = CONV_COPY_SHALLOW);
 
 ECSVRNAMELIST *List_to_LPECSVRNAMELIST(PyObject *object);
