@@ -5,17 +5,11 @@
 #ifndef PLATFORM_H
 #define PLATFORM_H
 
-#include <kopano/zcdefs.h>
-
-enum {
-	KC_DESIRED_FILEDES = 8192,
-};
-
   #ifdef HAVE_CONFIG_H
   #include "config.h"
   #endif
   #include <kopano/platform.linux.h>
-#include <chrono>
+#include <kopano/zcdefs.h>
 #include <mutex>
 #include <shared_mutex>
 #include <string>
@@ -26,8 +20,15 @@ enum {
 #include <endian.h>
 #include <pthread.h>
 
+enum {
+	KC_DESIRED_FILEDES = 8192,
+};
+
 namespace KC {
 
+#define S_IRWUG (S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP)
+#define S_IRWXUG (S_IRWXU | S_IRWXG)
+
 #define KOPANO_SYSTEM_USER		"SYSTEM"
 #define KOPANO_SYSTEM_USER_W	L"SYSTEM"
 
@@ -37,29 +38,6 @@ typedef int gsoap_size_t;
 /*
  * Platform independent functions
  */
-extern _kc_export FILETIME UnixTimeToFileTime(time_t);
-extern _kc_export time_t FileTimeToUnixTime(const FILETIME &);
-extern _kc_export void UnixTimeToFileTime(time_t, int *hi, unsigned int *lo);
-extern _kc_export LONG FileTimeToRTime(const FILETIME &);
-extern _kc_export int FileTimeToTimestamp(const FILETIME &, time_t &, char *, size_t);
-extern _kc_export LONG UnixTimeToRTime(time_t);
-extern _kc_export time_t RTimeToUnixTime(LONG rtime);
-extern _kc_export struct tm *gmtime_safe(time_t, struct tm *);
-extern _kc_export double timespec2dbl(const struct timespec &);
-extern bool operator==(const FILETIME &, const FILETIME &) noexcept;
-extern _kc_export bool operator >(const FILETIME &, const FILETIME &) noexcept;
-extern bool operator>=(const FILETIME &, const FILETIME &) noexcept;
-extern _kc_export bool operator <(const FILETIME &, const FILETIME &) noexcept;
-extern bool operator<=(const FILETIME &, const FILETIME &) noexcept;
-
-/* convert struct tm to time_t in timezone UTC0 (GM time) */
-#ifndef HAVE_TIMEGM
-time_t timegm(struct tm *t);
-#endif
-
-// mkdir -p
-extern _kc_export int CreatePath(std::string, unsigned int = 0770);
-
 // Random-number generators
 extern _kc_export void rand_init(void);
 extern _kc_export int rand_mt(void);
@@ -77,10 +55,7 @@ extern _kc_export char *get_password(const char *prompt);
 #define MEMORY_USAGE_STRING(str)			(str.capacity() + 1)
 #define MEMORY_USAGE_MULTIMAP(items, map)	MEMORY_USAGE_MAP(items, map)
 
-extern _kc_export ssize_t read_retry(int, void *, size_t);
-extern _kc_export ssize_t write_retry(int, const void *, size_t);
 extern _kc_export void set_thread_name(pthread_t, const std::string &);
-extern _kc_export bool force_buffers_to_disk(int fd);
 extern _kc_export int ec_relocate_fd(int);
 extern _kc_export void kcsrv_blocksigs(void);
 extern _kc_export unsigned long kc_threadid(void);
@@ -97,14 +72,6 @@ template<typename T> static inline constexpr const IID &iid_of(const T &)
 	return iid_of<typename std::remove_cv<typename std::remove_pointer<T>::type>::type>();
 }
 
-using time_point = std::chrono::time_point<std::chrono::steady_clock>;
-using time_duration = std::chrono::steady_clock::duration;
-
-template<typename T> static constexpr inline double dur2dbl(const T &t)
-{
-	return std::chrono::duration_cast<std::chrono::duration<double>>(t).count();
-}
-
 #if (defined(__BYTE_ORDER) && __BYTE_ORDER == __BIG_ENDIAN) || \
     (defined(_BYTE_ORDER) && _BYTE_ORDER == _BIG_ENDIAN)
 	/* We need to use constexpr functions, and htole16 unfortunately is not. */
