@@ -19,6 +19,7 @@
 #include <openssl/md5.h>
 
 struct SBinary;
+struct option;
 
 namespace KC {
 
@@ -69,7 +70,7 @@ static inline std::wstring wstringify(unsigned int x)
 extern _kc_export std::string stringify_hex(unsigned int);
 extern _kc_export std::string stringify_signed(int);
 extern _kc_export std::string stringify_int64(int64_t, bool usehex = false);
-extern _kc_export std::string stringify_float(float);
+extern _kc_export std::string stringify_float(double);
 extern _kc_export std::string stringify_double(double, int prec = 18, bool locale = false);
 extern _kc_export std::wstring wstringify_hex(unsigned int);
 
@@ -98,6 +99,8 @@ extern _kc_export std::string hex2bin(const std::wstring &);
 extern _kc_export std::string bin2hex(const std::string &);
 extern _kc_export std::string bin2hex(size_t len, const void *input);
 extern _kc_export std::string bin2hex(const SBinary &);
+extern _kc_export std::string bin2txt(const void *, size_t);
+extern _kc_export std::string bin2txt(const SBinary &);
 extern _kc_export std::string urlEncode(const std::string &);
 extern _kc_export std::string urlEncode(const std::wstring &, const char *charset);
 extern _kc_export std::string urlEncode(const wchar_t *input, const char *charset);
@@ -217,6 +220,8 @@ extern _kc_export std::string string_strip_crlf(const char *);
 extern _kc_export bool SymmetricIsCrypted(const char *);
 extern _kc_export std::string SymmetricDecrypt(const char *);
 extern _kc_export std::string content_type_get_charset(const char *in, const char *dflt);
+/* Permit unknown long options, move them to end of argv like arguments */
+extern _kc_export int my_getopt_long_permissive(int, char **, const char *, const struct option *, int *);
 
 } /* namespace */
 
