@@ -1,18 +1,6 @@
 /*
+ * SPDX-License-Identifier: AGPL-3.0-only
  * Copyright 2005 - 2016 Zarafa and its licensors
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
  */
 
 /**
@@ -108,11 +96,11 @@ information and delegate access to accounts.
  * calendar: Free, Busy, Tentative, or Out of Office.
  */
 enum FBStatus {
-	fbFree	= 0,					/**< Free */
-	fbTentative = fbFree + 1,		/**< Tentative */
-	fbBusy	= fbTentative + 1,		/**< Busy */
-	fbOutOfOffice	= fbBusy + 1,	/**< Out Of Office */
-	fbKopanoAllBusy = 1000			/**< Internal used */
+	fbFree,				/**< Free */
+	fbTentative,			/**< Tentative */
+	fbBusy,				/**< Busy */
+	fbOutOfOffice,			/**< Out Of Office */
+	fbKopanoAllBusy = 1000		/**< Internal used */
 };
 
 /**
@@ -149,12 +137,6 @@ typedef struct FBUser *LPFBUser;
  */
 class IFreeBusyUpdate : public virtual IUnknown {
 public:
-	/**
-	 * Unknown function, Possible reload the freebusydata ?
-	 * @return This member must return S_OK
-	 */
-	virtual HRESULT Reload() = 0;
-
 	/**
 	 * Add freebusy blocks, May be called more than once successively
 	 * Alternative name: AddAppt
@@ -163,15 +145,6 @@ public:
 	 */
 	virtual HRESULT PublishFreeBusy(const FBBlock_1 *b, ULONG nblks) = 0;
 
-	/**
-	 * Unknown function, this member not supported
-	 *
-	 * @note The variables of the function are possible wrong should be like, 
-	          int IFreeBusyUpdate__RemoveAppt(int,int,int,int);
-	 * @return This member must return S_OK
-	 */
-	virtual HRESULT RemoveAppt() = 0;
-
 	/**
 	 * Remove all Freebusy data
 	 * Alternative name: RemoveAllAppt
@@ -179,34 +152,10 @@ public:
 	 */
 	virtual HRESULT ResetPublishedFreeBusy() = 0;
 
-	/**
-	 * Unknown function, this member not supported
-	 *
-	 * @note The variables of the function are possible wrong
-	 * @return This member must return S_OK
-	 */
-	virtual HRESULT ChangeAppt() = 0;
-
 	/**
 	 * Save the freebusydata with time frame between the begintime and endtime.
 	 */
 	virtual HRESULT SaveChanges(const FILETIME &start, const FILETIME &end) = 0;
-
-	/**
-	 * Unknown function, this member not supported
-	 *
-	 * @note The variables of the function are possible wrong
-	 * @return This member must return S_OK
-	 */
-	virtual HRESULT GetFBTimes() = 0;
-
-	/**
-	 * Unknown function, this member not supported
-	 *
-	 * @note The variables of the function are possible wrong
-	 * @return This member must return S_OK
-	 */
-	virtual HRESULT Intersect() = 0;
 };
 
 /**
@@ -299,12 +248,6 @@ public:
  */
 class IFreeBusyData : public virtual IUnknown {
 public:
-	
-	/**
-	 * This member not supported must return E_NOTIMPL.
-	 */
-	virtual HRESULT Reload(void*) = 0;
-
 	/**
 	 * Gets an interface for a user that enumerates free/busy blocks of data within a 
 	 * specified time range.
@@ -323,26 +266,11 @@ public:
 	 */
 	virtual HRESULT EnumBlocks(IEnumFBBlock **ppenumfb, const FILETIME &start, const FILETIME &end) = 0;
 
-	/**
-	 * This member not supported must return E_NOTIMPL.
-	 */
-	virtual HRESULT Merge(void *) = 0;
-
 	/**
 	 * This member not supported must return E_NOTIMPL.
 	 */
 	virtual HRESULT GetDelegateInfo(void *) = 0;
 
-	/**
-	 * This member not supported must return S_OK.
-	 */
-	virtual HRESULT FindFreeBlock(LONG, LONG, LONG, BOOL, LONG, LONG, LONG, FBBlock_1 *) = 0;
-
-	/**
-	 * This member not supported must return E_NOTIMPL.
-	 */
-	virtual HRESULT InterSect(void *, LONG, void *) = 0;
-
 	/**
 	 * Sets the range of time for an enumeration of free/busy block of data for a user.
 	 *
@@ -360,12 +288,6 @@ public:
 	 */
 	virtual HRESULT SetFBRange(LONG rtmStart, LONG rtmEnd) = 0;
 
-	/**
-	 * This member not supported must return E_NOTIMPL.
-	 */
-	virtual HRESULT NextFBAppt(void *, ULONG, void *, ULONG, void *, void *) = 0;
-
-
 	/**
 	 * Gets a preset time range for an enumeration of free/busy blocks of data for a user.
 	 *
@@ -499,11 +421,6 @@ public:
 	 */
 	virtual HRESULT AdviseFreeBusy(void *) = 0;
 
-	/**
-	 * This member not supported must return E_NOTIMPL.
-	 */
-	virtual HRESULT Reload(void *) = 0;
-
 	/**
 	 * This member not supported must return E_NOTIMPL.
 	 */
