@@ -12,16 +12,16 @@
 #include <mapix.h>
 #include <kopano/Util.h>
 #include <list>
-#include "TimeUtil.h"
+#include <kopano/timeutil.hpp>
 #include "freebusy.h"
 #include "freebusyutil.h"
 
 namespace KC {
 
-class _kc_export recurrence _kc_final {
+class _kc_export recurrence KC_FINAL {
 public:
 	HRESULT HrLoadRecurrenceState(const char *data, size_t len, ULONG flags) { return m_sRecState.ParseBlob(data, len, flags); }
-	HRESULT HrGetRecurrenceState(char **lppData, unsigned int *lpulLen, void *base = NULL);
+	HRESULT HrGetRecurrenceState(char **lppData, size_t *lpulLen, void *base = NULL);
 	void HrGetHumanReadableString(std::string *);
 	HRESULT HrGetItems(time_t start, time_t end, const TIMEZONE_STRUCT &ttZinfo, ULONG ulBusyStatus, OccrInfo **lppFbBlock, ULONG *lpcValues, bool last = false);
 	enum freq_type { DAILY, WEEKLY, MONTHLY, YEARLY };
