@@ -1,17 +1,6 @@
 /*
+ * SPDX-License-Identifier: AGPL-3.0-only
  * Copyright 2005 - 2016 Zarafa and its licensors
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -29,10 +18,6 @@
 
 #define MAPI_DIM
 
-#ifndef BEGIN_INTERFACE
-#define BEGIN_INTERFACE
-#endif
-
 /*
  *  This flag is used in many different MAPI calls to signify that
  *  the object opened by the call should be modifiable (MAPI_MODIFY).
@@ -90,13 +75,12 @@ struct ENTRYID {
 };
 typedef struct ENTRYID *LPENTRYID;
 
-#define CbNewENTRYID(_cb)	(offsetof(ENTRYID,ab) + (_cb))
-#define CbENTRYID(_cb)		(offsetof(ENTRYID,ab) + (_cb))
-#define SizedENTRYID(_cb, _name) \
-struct _ENTRYID_ ## _name { \
-    BYTE    abFlags[4]; \
-    BYTE    ab[_cb]; \
-} _name
+#define CbNewENTRYID(cb) (offsetof(ENTRYID, ab) + (cb))
+#define CbENTRYID(cb) (offsetof(ENTRYID, ab) + (cb))
+#define SizedENTRYID(cb, name) \
+struct ENTRYID_ ## name { \
+	BYTE abFlags[4], ab[cb]; \
+} name
 
 /* Byte-order-independent version of GUID (world-unique identifier) */
 struct MAPIUID {
@@ -114,7 +98,7 @@ typedef struct MAPIUID *LPMAPIUID;
  * the flag that specifies whether the recipient gets TNEF or not.
  */
 #define MAPI_ONE_OFF_UID { 0x81, 0x2b, 0x1f, 0xa4, 0xbe, 0xa3, 0x10, 0x19, \
-                           0x9d, 0x6e, 0x00, 0xdd, 0x01, 0x0f, 0x54, 0x02 }
+                           0x9d, 0x6e, 0x00, 0xdd, 0x01, 0x0f, 0x54, 0x02 } /* MUIDOOP */
 #define MAPI_ONE_OFF_UNICODE        0x8000
 #define MAPI_ONE_OFF_NO_RICH_INFO   0x0001
 
@@ -132,17 +116,6 @@ typedef struct MAPIUID *LPMAPIUID;
 #define MAPI_SESSION    ((ULONG) 0x0000000B)
 #define MAPI_FORMINFO   ((ULONG) 0x0000000C)
 
-
-/*
- *  Maximum length of profile names and passwords, not including
- *  the null termination character.
- */
-    /* unused? */
-#define cchProfileNameMax   64
-#define cchProfilePassMax   64
-
-
-
 /* Property Types */
 #define MV_FLAG         0x1000
 
@@ -238,19 +211,18 @@ struct SPropTagArray {
 };
 typedef struct SPropTagArray *LPSPropTagArray;
 
-#define CbNewSPropTagArray(_ctag) \
-    (offsetof(SPropTagArray,aulPropTag) + (_ctag)*sizeof(ULONG))
-#define CbSPropTagArray(_lparray) \
+#define CbNewSPropTagArray(ctag) \
+	(offsetof(SPropTagArray, aulPropTag) + (ctag) * sizeof(ULONG))
+#define CbSPropTagArray(lparray) \
     (offsetof(SPropTagArray,aulPropTag) + \
-    (UINT)((_lparray)->cValues)*sizeof(ULONG))
+	static_cast<UINT>((lparray)->cValues) * sizeof(ULONG))
 /* SPropTagArray */
-#define SizedSPropTagArray(_ctag, _name) \
-struct _SPropTagArray_ ## _name { \
-    ULONG   cValues; \
-    ULONG   aulPropTag[_ctag]; \
+#define SizedSPropTagArray(ctag, name) \
+struct SPropTagArray_ ## name { \
+	unsigned int cValues, aulPropTag[ctag]; \
 	operator SPropTagArray &() { return *reinterpret_cast<SPropTagArray *>(this); } \
 	operator const SPropTagArray *(void) const { return reinterpret_cast<const SPropTagArray *>(this); } \
-} _name
+} name
 
 
 /* Property Value */
@@ -371,16 +343,14 @@ union __UPV {
 };
 
 struct SPropValue {
-    ULONG       ulPropTag;
-    ULONG       dwAlignPad;
+	ULONG ulPropTag, dwAlignPad;
     union __UPV  Value;
 };
 typedef struct SPropValue *LPSPropValue;
 
 /* Property Problem and Property Problem Arrays */
 struct SPropProblem {
-    ULONG   ulIndex;
-    ULONG   ulPropTag;
+	ULONG ulIndex, ulPropTag;
     SCODE   scode;
 };
 typedef struct SPropProblem *LPSPropProblem;
@@ -393,17 +363,16 @@ struct SPropProblemArray {
 };
 typedef struct SPropProblemArray *LPSPropProblemArray;
 
-#define CbNewSPropProblemArray(_cprob) \
-    (offsetof(SPropProblemArray,aProblem) + (_cprob)*sizeof(SPropProblem))
-#define CbSPropProblemArray(_lparray) \
+#define CbNewSPropProblemArray(cprob) \
+	(offsetof(SPropProblemArray, aProblem) + (cprob) * sizeof(SPropProblem))
+#define CbSPropProblemArray(lparray) \
     (offsetof(SPropProblemArray,aProblem) + \
-    (UINT) ((_lparray)->cProblem*sizeof(SPropProblem)))
-#define SizedSPropProblemArray(_cprob, _name) \
-struct _SPropProblemArray_ ## _name { \
+	static_cast<UINT>((lparray)->cProblem * sizeof(SPropProblem)))
+#define SizedSPropProblemArray(cprob, name) \
+struct SPropProblemArray_ ## name { \
     ULONG           cProblem; \
-    SPropProblem    aProblem[_cprob]; \
-} _name
-
+	SPropProblem aProblem[cprob]; \
+} name
 
 /* Entry List */
 typedef SBinaryArray ENTRYLIST, *LPENTRYLIST;
@@ -419,8 +388,7 @@ typedef struct FLATENTRY *LPFLATENTRY;
 struct FLATENTRYLIST {
 	FLATENTRYLIST(void) = delete;
 	template<typename T> FLATENTRYLIST(std::initializer_list<T>) = delete;
-    ULONG       cEntries;
-    ULONG       cbEntries;
+	ULONG cEntries, cbEntries;
     BYTE        abEntries[MAPI_DIM];
 };
 typedef struct FLATENTRYLIST *LPFLATENTRYLIST;
@@ -436,26 +404,24 @@ typedef struct MTSID *LPMTSID;
 struct FLATMTSIDLIST {
 	FLATMTSIDLIST(void) = delete;
 	template<typename T> FLATMTSIDLIST(std::initializer_list<T>) = delete;
-    ULONG       cMTSIDs;
-    ULONG       cbMTSIDs;
+	ULONG cMTSIDs, cbMTSIDs;
     BYTE        abMTSIDs[MAPI_DIM];
 };
 typedef struct FLATMTSIDLIST *LPFLATMTSIDLIST;
 
-#define CbNewFLATENTRY(_cb)     (offsetof(FLATENTRY,abEntry) + (_cb))
-#define CbFLATENTRY(_lpentry)   (offsetof(FLATENTRY,abEntry) + (_lpentry)->cb)
-#define CbNewFLATENTRYLIST(_cb) (offsetof(FLATENTRYLIST,abEntries) + (_cb))
-#define CbFLATENTRYLIST(_lplist) (offsetof(FLATENTRYLIST,abEntries) + (_lplist)->cbEntries)
-#define CbNewMTSID(_cb)         (offsetof(MTSID,ab) + (_cb))
-#define CbMTSID(_lpentry)       (offsetof(MTSID,ab) + (_lpentry)->cb)
-#define CbNewFLATMTSIDLIST(_cb) (offsetof(FLATMTSIDLIST,abMTSIDs) + (_cb))
-#define CbFLATMTSIDLIST(_lplist) (offsetof(FLATMTSIDLIST,abMTSIDs) + (_lplist)->cbMTSIDs)
+#define CbNewFLATENTRY(cb) (offsetof(FLATENTRY, abEntry) + (cb))
+#define CbFLATENTRY(lpentry) (offsetof(FLATENTRY, abEntry) + (lpentry)->cb)
+#define CbNewFLATENTRYLIST(cb) (offsetof(FLATENTRYLIST, abEntries) + (cb))
+#define CbFLATENTRYLIST(lplist) (offsetof(FLATENTRYLIST, abEntries) + (lplist)->cbEntries)
+#define CbNewMTSID(cb) (offsetof(MTSID, ab) + (cb))
+#define CbMTSID(lpentry) (offsetof(MTSID, ab) + (lpentry)->cb)
+#define CbNewFLATMTSIDLIST(cb) (offsetof(FLATMTSIDLIST, abMTSIDs) + (cb))
+#define CbFLATMTSIDLIST(lplist) (offsetof(FLATMTSIDLIST, abMTSIDs) + (lplist)->cbMTSIDs)
 /* No SizedXXX macros for these types. */
 
 /* ADRENTRY, ADRLIST */
 struct ADRENTRY {
-    ULONG           ulReserved1;
-    ULONG           cValues;
+	ULONG ulReserved1, cValues;
     LPSPropValue    rgPropVals;
 	inline const SPropValue *cfind(ULONG tag) const;
 };
@@ -469,21 +435,20 @@ struct ADRLIST {
 };
 typedef struct ADRLIST *LPADRLIST;
 
-#define CbNewADRLIST(_centries) \
-    (offsetof(ADRLIST,aEntries) + (_centries)*sizeof(ADRENTRY))
-#define CbADRLIST(_lpadrlist) \
-    (offsetof(ADRLIST,aEntries) + (UINT)(_lpadrlist)->cEntries*sizeof(ADRENTRY))
-#define SizedADRLIST(_centries, _name) \
-struct _ADRLIST_ ## _name { \
+#define CbNewADRLIST(centries) \
+	(offsetof(ADRLIST, aEntries) + (centries) * sizeof(ADRENTRY))
+#define CbADRLIST(lpadrlist) \
+	(offsetof(ADRLIST, aEntries) + static_cast<UINT>(lpadrlist)->cEntries * sizeof(ADRENTRY))
+#define SizedADRLIST(centries, name) \
+struct ADRLIST_ ## name { \
     ULONG           cEntries; \
-    ADRENTRY        aEntries[_centries]; \
+	ADRENTRY aEntries[centries]; \
     operator const ADRLIST *(void) const { return reinterpret_cast<const ADRLIST *>(this); } \
-} _name
+} name
 
 /* SRow, SRowSet */
 struct SRow {
-    ULONG           ulAdrEntryPad;
-    ULONG           cValues;
+	ULONG ulAdrEntryPad, cValues;
     LPSPropValue    lpProps;
 	inline SPropValue *find(ULONG tag) const;
 	inline const SPropValue *cfind(ULONG tag) const;
@@ -499,15 +464,14 @@ struct SRowSet {
 };
 typedef struct SRowSet *LPSRowSet;
 
-#define CbNewSRowSet(_crow)     (offsetof(SRowSet,aRow) + (_crow)*sizeof(SRow))
-#define CbSRowSet(_lprowset)    (offsetof(SRowSet,aRow) + \
-                                    (UINT)((_lprowset)->cRows*sizeof(SRow)))
-#define SizedSRowSet(_crow, _name) \
-struct _SRowSet_ ## _name { \
+#define CbNewSRowSet(crow) (offsetof(SRowSet, aRow) + (crow) * sizeof(SRow))
+#define CbSRowSet(lprowset) (offsetof(SRowSet, aRow) + \
+	static_cast<UINT>((lprowset)->cRows * sizeof(SRow)))
+#define SizedSRowSet(crow, name) \
+struct SRowSet_ ## name { \
     ULONG           cRows; \
-    SRow            aRow[_crow]; \
-} _name
-
+	SRow aRow[crow]; \
+} name
 
 extern "C" {
 /* MAPI Allocation Routines */
@@ -531,44 +495,6 @@ typedef ALLOCATEMORE* LPALLOCATEMORE;
 typedef FREEBUFFER* LPFREEBUFFER;
 }
 
-/* MAPI Component Object Model Macros */
-/* #if defined(MAPI_IF) && (!defined(__cplusplus) || defined(CINTERFACE)) */
-/* #define DECLARE_MAPI_INTERFACE(iface)                                   \ */
-/*         typedef struct iface##Vtbl iface##Vtbl, * iface;            \ */
-/*         struct iface##Vtbl */
-/* #define DECLARE_MAPI_INTERFACE_(iface, baseiface)                       \ */
-/*         DECLARE_MAPI_INTERFACE(iface) */
-/* #define DECLARE_MAPI_INTERFACE_PTR(iface, piface)                       \ */
-/*         typedef struct iface##Vtbl iface##Vtbl, * iface, * * piface; */
-/* #else */
-/* #define DECLARE_MAPI_INTERFACE(iface)                                   \ */
-/*         DECLARE_INTERFACE(iface) */
-/* #define DECLARE_MAPI_INTERFACE_(iface, baseiface)                       \ */
-/*         DECLARE_INTERFACE_(iface, baseiface) */
-/* #ifdef __cplusplus */
-/* #define DECLARE_MAPI_INTERFACE_PTR(iface, piface)                       \ */
-/*         interface iface; typedef iface * piface */
-/* #else */
-/* #define DECLARE_MAPI_INTERFACE_PTR(iface, piface)                       \ */
-/*         typedef interface iface iface, * piface */
-/* #endif */
-/* #endif */
-/* /\*--*\/ */
-
-/* #define MAPIMETHOD(method)              MAPIMETHOD_(HRESULT, method) */
-/* #define MAPIMETHOD_(type, method)       STDMETHOD_(type, method) */
-/* #define MAPIMETHOD_DECLARE(type, method, prefix) \ */
-/*         STDMETHODIMP_(type) prefix##method */
-/* #define MAPIMETHOD_TYPEDEF(type, method, prefix) \ */
-/*         typedef type (STDMETHODCALLTYPE prefix##method##_METHOD) */
-
-/* #define MAPI_IUNKNOWN_METHODS(IPURE)                                    \ */
-/*     MAPIMETHOD(QueryInterface)                                          \ */
-/*         (THIS_ REFIID riid, LPVOID * ppvObj) IPURE;                 \ */
-/*     MAPIMETHOD_(ULONG,AddRef)  (THIS) IPURE;                            \ */
-/*     MAPIMETHOD_(ULONG,Release) (THIS) IPURE;                            \ */
-
-
 /* Pointers to MAPI Interfaces */
 typedef const IID* LPCIID;
 
@@ -576,10 +502,8 @@ typedef const IID* LPCIID;
 /* Extended MAPI Error Information */
 struct MAPIERROR {
     ULONG   ulVersion;
-    LPTSTR  lpszError;
-    LPTSTR  lpszComponent;
-    ULONG   ulLowLevelError;
-    ULONG   ulContext;
+	TCHAR *lpszError, *lpszComponent;
+	ULONG ulLowLevelError, ulContext;
 };
 typedef MAPIERROR *LPMAPIERROR;
 
@@ -769,7 +693,7 @@ public:
     virtual HRESULT GetContentsTable(ULONG ulFlags, LPMAPITABLE* lppTable) = 0;
     virtual HRESULT GetHierarchyTable(ULONG ulFlags, LPMAPITABLE* lppTable) = 0;
 	virtual HRESULT OpenEntry(ULONG eid_size, const ENTRYID *eid, const IID *intf, ULONG flags, ULONG *obj_type, IUnknown **) = 0;
-    virtual HRESULT SetSearchCriteria(LPSRestriction lpRestriction, LPENTRYLIST lpContainerList, ULONG ulSearchFlags) = 0;
+	virtual HRESULT SetSearchCriteria(const SRestriction *, const ENTRYLIST *container, ULONG flags) = 0;
     virtual HRESULT GetSearchCriteria(ULONG ulFlags, LPSRestriction* lppRestriction, LPENTRYLIST* lppContainerList,
 				      ULONG* lpulSearchState) = 0;
 };
@@ -791,6 +715,8 @@ IID_OF(IMAPIContainer)
  *      fnevSearchComplete      OBJECT_NOTIFICATION
  *      fnevTableModified       TABLE_NOTIFICATION
  *      fnevStatusObjectModified ?
+ *      fnevObjTypeMessage      OBJECT_NOTIFICATION
+ *      fnevObjTypeFolder       OBJECT_NOTIFICATION
  *
  *      fnevExtended            EXTENDED_NOTIFICATION
  */
@@ -804,6 +730,9 @@ IID_OF(IMAPIContainer)
 #define fnevSearchComplete          ((ULONG) 0x00000080)
 #define fnevTableModified           ((ULONG) 0x00000100)
 #define fnevStatusObjectModified    ((ULONG) 0x00000200)
+#define fnevObjTypeMessage          ((ULONG) 0x00010000)
+#define fnevObjTypeFolder           ((ULONG) 0x00020000)
+#define fnevIgnoreCounters          ((ULONG) 0x00040000)
 #define fnevReservedForMapi         ((ULONG) 0x40000000)
 #define fnevExtended                ((ULONG) 0x80000000)
 
@@ -840,8 +769,7 @@ struct NEWMAIL_NOTIFICATION {
 struct OBJECT_NOTIFICATION {
     ULONG               cbEntryID;
     LPENTRYID           lpEntryID;
-    ULONG               ulObjType;
-    ULONG               cbParentID;
+	ULONG ulObjType, cbParentID;
     LPENTRYID           lpParentID;
     ULONG               cbOldID;
     LPENTRYID           lpOldID;
@@ -860,8 +788,7 @@ struct TABLE_NOTIFICATION {
 };
 
 struct EXTENDED_NOTIFICATION {
-    ULONG       ulEvent;
-    ULONG       cb;
+	ULONG ulEvent, cb;
     LPBYTE      pbEventParameters;
 };
 
@@ -873,8 +800,7 @@ struct STATUS_OBJECT_NOTIFICATION {
 };
 
 struct NOTIFICATION {
-    ULONG   ulEventType;
-    ULONG   ulAlignPad;
+	ULONG ulEventType, ulAlignPad;
     union {
         ERROR_NOTIFICATION          err;
         NEWMAIL_NOTIFICATION        newmail;
@@ -958,7 +884,7 @@ public:
     virtual HRESULT GetOutgoingQueue(ULONG ulFlags, LPMAPITABLE *lppTable) = 0;
     virtual HRESULT SetLockState(LPMESSAGE lpMessage,ULONG ulLockState) = 0;
 	virtual HRESULT FinishedMsg(ULONG flags, ULONG eid_size, const ENTRYID *) = 0;
-    virtual HRESULT NotifyNewMail(LPNOTIFICATION lpNotification) = 0;
+	virtual HRESULT NotifyNewMail(const NOTIFICATION *lpNotification) = 0;
 };
 IID_OF(IMsgStore)
 
@@ -985,20 +911,17 @@ struct SSortOrderSet {
 };
 typedef struct SSortOrderSet *LPSSortOrderSet;
 
-#define CbNewSSortOrderSet(_csort) \
-    (offsetof(SSortOrderSet,aSort) + (_csort)*sizeof(SSortOrder))
-#define CbSSortOrderSet(_lpset) \
+#define CbNewSSortOrderSet(csort) \
+    (offsetof(SSortOrderSet, aSort) + (csort) * sizeof(SSortOrder))
+#define CbSSortOrderSet(lpset) \
     (offsetof(SSortOrderSet,aSort) + \
-    (UINT)((_lpset)->cSorts*sizeof(SSortOrder)))
-#define SizedSSortOrderSet(_csort, _name) \
-struct _SSortOrderSet_ ## _name { \
-    ULONG           cSorts;         \
-    ULONG           cCategories;    \
-    ULONG           cExpanded;      \
-    SSortOrder      aSort[_csort];  \
+	static_cast<UINT>((lpset)->cSorts * sizeof(SSortOrder)))
+#define SizedSSortOrderSet(csort, name) \
+struct SSortOrderSet_ ## name { \
+	ULONG cSorts, cCategories, cExpanded; \
+	SSortOrder aSort[csort]; \
 	operator const SSortOrderSet *(void) const { return reinterpret_cast<const SSortOrderSet *>(this); } \
-} _name
-
+} name
 
 #define FOLDER_ROOT             ((ULONG) 0x00000000)
 #define FOLDER_GENERIC          ((ULONG) 0x00000001)
@@ -1129,8 +1052,8 @@ struct FlagList {
 typedef struct FlagList *LPFlagList;
 
 /* Our parts. */
-#define CbNewFlagList(_cflags) \
-    (offsetof(FlagList,ulFlag) + (_cflags)*sizeof(ULONG))
+#define CbNewFlagList(cflags) \
+	(offsetof(FlagList, ulFlag) + (cflags) * sizeof(ULONG))
 
 #define AB_RECIPIENTS           ((ULONG) 0x00000001)
 #define AB_SUBCONTAINERS        ((ULONG) 0x00000002)
@@ -1151,8 +1074,8 @@ namespace KC {
 class IABContainer_DistList_base : public virtual IMAPIContainer {
 	public:
 	virtual HRESULT CreateEntry(ULONG eid_size, const ENTRYID *eid, ULONG flags, IMAPIProp **) = 0;
-	virtual HRESULT CopyEntries(ENTRYLIST *, ULONG ui_param, IMAPIProgress *, ULONG flags) = 0;
-	virtual HRESULT DeleteEntries(ENTRYLIST *, ULONG flags) = 0;
+	virtual HRESULT CopyEntries(const ENTRYLIST *, ULONG ui_param, IMAPIProgress *, ULONG flags) = 0;
+	virtual HRESULT DeleteEntries(const ENTRYLIST *, ULONG flags) = 0;
 	virtual HRESULT ResolveNames(const SPropTagArray *, ULONG flags, ADRLIST *, FlagList *) = 0;
 };
 
@@ -1173,7 +1096,7 @@ IID_OF(IABContainer)
 */
 #define MAPI_SEND_NO_RICH_INFO      ((ULONG) 0x00010000)
 
-#define MAPI_DIAG(_code)    ((LONG) _code)
+#define MAPI_DIAG(code) static_cast<LONG>(code)
 
 #define MAPI_DIAG_NO_DIAGNOSTIC                     MAPI_DIAG( -1 )
 #define MAPI_DIAG_OR_NAME_UNRECOGNIZED              MAPI_DIAG( 0 )
@@ -1353,39 +1276,29 @@ struct SNotRestriction {
 };
 
 struct SContentRestriction {
-    ULONG           ulFuzzyLevel;
-    ULONG           ulPropTag;
+	ULONG ulFuzzyLevel, ulPropTag;
     LPSPropValue    lpProp;
 };
 
 struct SBitMaskRestriction {
-    ULONG           relBMR;
-    ULONG           ulPropTag;
-    ULONG           ulMask;
+	ULONG relBMR, ulPropTag, ulMask;
 };
 
 struct SPropertyRestriction {
-    ULONG           relop;
-    ULONG           ulPropTag;
+	ULONG relop, ulPropTag;
     LPSPropValue    lpProp;
 };
 
 struct SComparePropsRestriction {
-    ULONG           relop;
-    ULONG           ulPropTag1;
-    ULONG           ulPropTag2;
+	ULONG relop, ulPropTag1, ulPropTag2;
 };
 
 struct SSizeRestriction {
-    ULONG           relop;
-    ULONG           ulPropTag;
-    ULONG           cb;
+	ULONG relop, ulPropTag, cb;
 };
 
 struct SExistRestriction {
-    ULONG           ulReserved1;
-    ULONG           ulPropTag;
-    ULONG           ulReserved2;
+	ULONG ulReserved1, ulPropTag, ulReserved2;
 };
 
 struct SSubRestriction {
@@ -1675,15 +1588,12 @@ struct ADRPARM {
     LPFNABSDI       lpfnABSDI;
     LPFNDISMISS     lpfnDismiss;
     LPVOID          lpvDismissContext;
-    LPTSTR          lpszCaption;
-    LPTSTR          lpszNewEntryTitle;
-    LPTSTR          lpszDestWellsTitle;
+	TCHAR *lpszCaption, *lpszNewEntryTitle, *lpszDestWellsTitle;
     ULONG           cDestFields;
     ULONG           nDestFieldFocus;
     LPTSTR *    lppszDestTitles;
     ULONG *     lpulDestComps;
-    LPSRestriction  lpContRestriction;
-    LPSRestriction  lpHierRestriction;
+	SRestriction *lpContRestriction, *lpHierRestriction;
 };
 typedef struct ADRPARM *LPADRPARM;
 
@@ -1748,26 +1658,22 @@ IID_OF(IMAPIControl)
 
 /* Labels */
 struct DTBLLABEL {
-    ULONG ulbLpszLabelName;
-    ULONG ulFlags;
+	ULONG ulbLpszLabelName, ulFlags;
 };
 typedef struct DTBLLABEL *LPDTBLLABEL;
 #define SizedDtblLabel(n,u) \
-struct _DTBLLABEL_ ## u { \
+struct DTBLLABEL_ ## u { \
     DTBLLABEL   dtbllabel; \
     TCHAR       lpszLabelName[n]; \
 } u
 
 /*  Simple Text Edits  */
 struct DTBLEDIT {
-    ULONG ulbLpszCharsAllowed;
-    ULONG ulFlags;
-    ULONG ulNumCharsAllowed;
-    ULONG ulPropTag;
+	ULONG ulbLpszCharsAllowed, ulFlags, ulNumCharsAllowed, ulPropTag;
 };
 typedef struct DTBLEDIT *LPDTBLEDIT;
 #define SizedDtblEdit(n,u) \
-struct _DTBLEDIT_ ## u { \
+struct DTBLEDIT_ ## u { \
     DTBLEDIT    dtbledit; \
     TCHAR       lpszCharsAllowed[n]; \
 } u
@@ -1777,23 +1683,18 @@ struct _DTBLEDIT_ ## u { \
 #define MAPI_NO_VBAR        ((ULONG) 0x00000002)
 
 struct DTBLLBX {
-    ULONG ulFlags;
-    ULONG ulPRSetProperty;
-    ULONG ulPRTableName;
+	ULONG ulFlags, ulPRSetProperty, ulPRTableName;
 };
 typedef struct DTBLLBX *LPDTBLLBX;
 
 /*  Combo Box   */
 struct DTBLCOMBOBOX {
-    ULONG ulbLpszCharsAllowed;
-    ULONG ulFlags;
-    ULONG ulNumCharsAllowed;
-    ULONG ulPRPropertyName;
-    ULONG ulPRTableName;
+	ULONG ulbLpszCharsAllowed, ulFlags, ulNumCharsAllowed;
+	ULONG ulPRPropertyName, ulPRTableName;
 };
 typedef struct DTBLCOMBOBOX *LPDTBLCOMBOBOX;
 #define SizedDtblComboBox(n,u) \
-struct _DTBLCOMBOBOX_ ## u { \
+struct DTBLCOMBOBOX_ ## u { \
     DTBLCOMBOBOX    dtblcombobox; \
     TCHAR           lpszCharsAllowed[n]; \
 } u
@@ -1801,22 +1702,17 @@ struct _DTBLCOMBOBOX_ ## u { \
 
 /*  Drop Down   */
 struct DTBLDDLBX {
-    ULONG ulFlags;
-    ULONG ulPRDisplayProperty;
-    ULONG ulPRSetProperty;
-    ULONG ulPRTableName;
+	ULONG ulFlags, ulPRDisplayProperty, ulPRSetProperty, ulPRTableName;
 };
 typedef struct DTBLDDLBX *LPDTBLDDLBX;
 
 /*  Check Box   */
 struct DTBLCHECKBOX {
-    ULONG ulbLpszLabel;
-    ULONG ulFlags;
-    ULONG ulPRPropertyName;
+	ULONG ulbLpszLabel, ulFlags, ulPRPropertyName;
 };
 typedef struct DTBLCHECKBOX *LPDTBLCHECKBOX;
 #define SizedDtblCheckBox(n,u) \
-struct _DTBLCHECKBOX_ ## u { \
+struct DTBLCHECKBOX_ ## u { \
     DTBLCHECKBOX    dtblcheckbox; \
     TCHAR       lpszLabel[n]; \
 } u
@@ -1824,12 +1720,11 @@ struct _DTBLCHECKBOX_ ## u { \
 
 /*  Group Box   */
 struct DTBLGROUPBOX {
-    ULONG ulbLpszLabel;
-    ULONG ulFlags;
+	ULONG ulbLpszLabel, ulFlags;
 };
 typedef struct DTBLGROUPBOX *LPDTBLGROUPBOX;
 #define SizedDtblGroupBox(n,u) \
-struct _DTBLGROUPBOX_ ## u { \
+struct DTBLGROUPBOX_ ## u { \
     DTBLGROUPBOX    dtblgroupbox; \
     TCHAR           lpszLabel[n]; \
 } u
@@ -1837,13 +1732,11 @@ struct _DTBLGROUPBOX_ ## u { \
 
 /*  Button control   */
 struct DTBLBUTTON {
-    ULONG ulbLpszLabel;
-    ULONG ulFlags;
-    ULONG ulPRControl;
+	ULONG ulbLpszLabel, ulFlags, ulPRControl;
 };
 typedef struct DTBLBUTTON *LPDTBLBUTTON;
 #define SizedDtblButton(n,u) \
-struct _DTBLBUTTON_ ## u { \
+struct DTBLBUTTON_ ## u { \
     DTBLBUTTON  dtblbutton; \
     TCHAR       lpszLabel[n]; \
 } u
@@ -1851,14 +1744,11 @@ struct _DTBLBUTTON_ ## u { \
 
 /*  Pages   */
 struct DTBLPAGE {
-    ULONG ulbLpszLabel;
-    ULONG ulFlags;
-    ULONG ulbLpszComponent;
-    ULONG ulContext;
+	ULONG ulbLpszLabel, ulFlags, ulbLpszComponent, ulContext;
 };
 typedef struct DTBLPAGE *LPDTBLPAGE;
 #define SizedDtblPage(n,n1,u) \
-struct _DTBLPAGE_ ## u { \
+struct DTBLPAGE_ ## u { \
     DTBLPAGE    dtblpage; \
     TCHAR       lpszLabel[n]; \
     TCHAR       lpszComponent[n1]; \
@@ -1867,15 +1757,12 @@ struct _DTBLPAGE_ ## u { \
 
 /*  Radio button   */
 struct DTBLRADIOBUTTON {
-    ULONG ulbLpszLabel;
-    ULONG ulFlags;
-    ULONG ulcButtons;
-    ULONG ulPropTag;
+	ULONG ulbLpszLabel, ulFlags, ulcButtons, ulPropTag;
     long lReturnValue;
 };
 typedef struct DTBLRADIOBUTTON *LPDTBLRADIOBUTTON;
 #define SizedDtblRadioButton(n,u) \
-struct _DTBLRADIOBUTTON_ ## u { \
+struct DTBLRADIOBUTTON_ ## u { \
     DTBLRADIOBUTTON dtblradiobutton; \
     TCHAR           lpszLabel[n]; \
 } u
@@ -1883,15 +1770,13 @@ struct _DTBLRADIOBUTTON_ ## u { \
 
 /*  MultiValued listbox */
 struct DTBLMVLISTBOX {
-    ULONG ulFlags;
-    ULONG ulMVPropTag;
+	ULONG ulFlags, ulMVPropTag;
 };
 typedef struct DTBLMVLISTBOX *LPDTBLMVLISTBOX;
 
 /*  MultiValued dropdown */
 struct DTBLMVDDLBX {
-    ULONG ulFlags;
-    ULONG ulMVPropTag;
+	ULONG ulFlags, ulMVPropTag;
 };
 typedef struct DTBLMVDDLBX *LPDTBLMVDDLBX;
 
