@@ -15,9 +15,9 @@ import time
 import icalmapi
 
 from MAPI import (
-    MAPI_MODIFY, MAPI_ASSOCIATED, KEEP_OPEN_READWRITE, ROW_ADD,
+    MAPI_MODIFY, MAPI_ASSOCIATED, ROW_ADD,
     RELOP_GT, RELOP_LT, RELOP_EQ, MAPI_CREATE,
-    DEL_ASSOCIATED, DEL_FOLDERS, DEL_MESSAGES,
+    DEL_ASSOCIATED, DEL_FOLDERS, DEL_MESSAGES, COPY_SUBFOLDERS,
     BOOKMARK_BEGINNING, ROW_REMOVE, MESSAGE_MOVE, FOLDER_MOVE,
     FOLDER_GENERIC, MAPI_UNICODE, FL_SUBSTRING, FL_IGNORECASE,
     SEARCH_RECURSIVE, SEARCH_REBUILD, PT_MV_BINARY, PT_BINARY,
@@ -66,7 +66,7 @@ from .errors import NotFoundError, ArgumentError
 from .query import _query_to_restriction
 
 from .compat import (
-    fake_unicode as _unicode, bdec as _bdec, benc as _benc, is_str
+    fake_unicode as _unicode, bdec as _bdec, benc as _benc
 )
 
 if sys.hexversion >= 0x03000000:
@@ -143,7 +143,7 @@ class Folder(Properties):
             return self._mapiobj
 
         try:
-            self._mapiobj = self.store.mapiobj.OpenEntry(self._entryid, IID_IMAPIFolder, MAPI_MODIFY | MAPI_DEFERRED_ERRORS)
+            self._mapiobj = self.store.mapiobj.OpenEntry(self._entryid, IID_IMAPIFolder, MAPI_MODIFY)
         except (MAPIErrorNotFound, MAPIErrorInvalidEntryid):
             try:
                 self._mapiobj = self.store.mapiobj.OpenEntry(self._entryid, IID_IMAPIFolder, MAPI_MODIFY | SHOW_SOFT_DELETES)
@@ -179,6 +179,7 @@ class Folder(Properties):
     @property
     def parent(self):
         """:class:`Parent <Folder>` folder"""
+
         parent_eid = self._get_fast(PR_PARENT_ENTRYID)
         if parent_eid:
             parent_eid = _benc(parent_eid)
@@ -478,9 +479,11 @@ class Folder(Properties):
                     break
 
     def create_item(self, eml=None, ics=None, vcf=None, load=None, loads=None, attachments=True, save=True, **kwargs): # XXX associated
-        item = _item.Item(self, eml=eml, ics=ics, vcf=vcf, load=load, loads=loads, attachments=attachments, create=True, save=save)
+        read = kwargs.get('read') # needs to be set before first save
+        item = _item.Item(self, eml=eml, ics=ics, vcf=vcf, load=load, loads=loads, attachments=attachments, create=True, save=save, read=read)
         for key, val in kwargs.items():
-            setattr(item, key, val)
+            if key != 'read':
+                setattr(item, key, val)
         return item
 
     # XXX: always hard delete or but we should also provide 'softdelete' which moves the item to the wastebasket
@@ -590,7 +593,7 @@ class Folder(Properties):
         if item_entryids:
             self.mapiobj.CopyMessages(item_entryids, IID_IMAPIFolder, folder.mapiobj, 0, None, (MESSAGE_MOVE if _delete else 0))
         for entryid in folder_entryids:
-            self.mapiobj.CopyFolder(entryid, IID_IMAPIFolder, folder.mapiobj, None, 0, None, (FOLDER_MOVE if _delete else 0))
+            self.mapiobj.CopyFolder(entryid, IID_IMAPIFolder, folder.mapiobj, None, 0, None, COPY_SUBFOLDERS | (FOLDER_MOVE if _delete else 0))
 
     def move(self, objects, folder):
         """Move items or subfolders to folder
@@ -612,6 +615,11 @@ class Folder(Properties):
                 return Folder(self.store, entryid)
             except (MAPIErrorInvalidEntryid, MAPIErrorNotFound, TypeError):
                 raise NotFoundError('no folder with entryid "%s"' % entryid)
+        elif path is None:
+            raise ArgumentError('missing argument to identify folder')
+
+        if path is None:
+            raise ArgumentError('no path or entryid specified')
 
         if '/' in path.replace('\\/', ''): # XXX MAPI folders may contain '/' (and '\') in their names..
             subfolder = self
@@ -926,7 +934,7 @@ class Folder(Properties):
 
     def search_wait(self):
         while True:
-            (restrict, list, state) = self.mapiobj.GetSearchCriteria(0)
+            (restrict, _, state) = self.mapiobj.GetSearchCriteria(0)
             if not state & SEARCH_REBUILD:
                 break
 
@@ -1005,6 +1013,8 @@ class Folder(Properties):
             return 'contacts'
         elif self.container_class == 'IPF.Appointment':
             return 'calendar'
+        else:
+            return 'folder'
 
     def __eq__(self, f): # XXX check same store?
         if isinstance(f, Folder):
