@@ -16,7 +16,8 @@ from MAPI import (
     ECImportContentsChanges, SYNC_E_IGNORE, WrapStoreEntryID,
     SYNC_NORMAL, SYNC_ASSOCIATED, SYNC_CATCHUP, SYNC_UNICODE, IStream,
     STREAM_SEEK_SET, RELOP_GE, RELOP_LT, ECImportHierarchyChanges,
-    ECImportAddressbookChanges, MAPI_MAILUSER,
+    ECImportAddressbookChanges, MAPI_MAILUSER, SYNC_READ_STATE,
+    MSGFLAG_READ,
 )
 from MAPI.Defs import (
     PpropFindProp
@@ -48,7 +49,10 @@ if sys.hexversion >= 0x03000000:
         from . import folder as _folder
     except ImportError: # pragma: no cover
         _folder = sys.modules[__package__+'.folder']
-    from . import user as _user
+    try:
+        from . import user as _user
+    except ImportError: # pragma: no cover
+        _user = sys.modules[__package__ + '.user']
     try:
         from . import store as _store
     except ImportError: # pragma: no cover
@@ -79,7 +83,7 @@ class TrackingHierarchyImporter(ECImportHierarchyChanges):
     def ImportFolderChange(self, props):
         if hasattr(self.importer, 'update'):
             eid = _benc(PpropFindProp(props, PR_ENTRYID).Value)
-            folder = self.importer.store.folder(entryid=eid)
+            folder = _folder.Folder(store=self.importer.store, entryid=eid)
             self.importer.update(folder)
 
     def ImportFolderDeletion(self, flags, sourcekeys):
@@ -151,7 +155,23 @@ class TrackingContentsImporter(ECImportContentsChanges):
                 self.stats['errors'] += 1
 
     def ImportPerUserReadStateChange(self, states):
-        pass
+        if self.skip:
+            return
+        try:
+            for state in states:
+                item = _item.Item()
+                item.server = self.server
+                if self.importer.store: # TODO system-wide?
+                    item.store = self.importer.store
+                item._sourcekey = _benc(state.SourceKey)
+                if hasattr(self.importer, 'read'):
+                    self.importer.read(item, bool(state.ulFlags & MSGFLAG_READ))
+
+        except Exception:
+            self.log.error('could not process readstate change')
+            self.log.error(traceback.format_exc())
+            if self.stats:
+                self.stats['errors'] += 1
 
     def UpdateState(self, stream):
         pass
@@ -241,7 +261,7 @@ def sync(server, syncobj, importer, state, max_changes, associated=False, window
         else:
             restriction = SAndRestriction(restrs)
 
-    flags = SYNC_NORMAL | SYNC_UNICODE
+    flags = SYNC_NORMAL | SYNC_UNICODE | SYNC_READ_STATE
     if associated:
         flags |= SYNC_ASSOCIATED
     try:
@@ -298,7 +318,23 @@ def sync(server, syncobj, importer, state, max_changes, associated=False, window
     exporter.UpdateState(stream)
 
     stream.Seek(0, STREAM_SEEK_SET)
-    return _benc(stream.Read(0xFFFFF))
+    state = _benc(stream.Read(0xFFFFF))
+
+    # because changes may be reordered for efficiency, we are not always
+    # linearly following the change journal. so the current state cannot
+    # always be represented as a single change id. instead, the current state
+    # may contain changes which have been synced, relative to a certain
+    # change id (so we have synced until this change id, plus these changes).
+
+    # in pyko though, we always sync until there are no further changes,
+    # so this should normally not occur.
+
+    # TODO add an ICS flag to disable reordering
+
+    if len(state) != 16:
+        log.error('sync state not 16 digits, expect problems')
+
+    return state
 
 def sync_gab(server, mapistore, importer, state):
     stream = IStream()
