@@ -26,16 +26,18 @@ import inetmapi
 import icalmapi
 
 from MAPI import (
-    KEEP_OPEN_READWRITE, PT_MV_BINARY, PT_BOOLEAN, MSGFLAG_READ,
+    PT_MV_BINARY, PT_BOOLEAN, MSGFLAG_READ,
     CLEAR_READ_FLAG, PT_MV_UNICODE, PT_BINARY, PT_LONG,
     MAPI_CREATE, MAPI_MODIFY, MAPI_DEFERRED_ERRORS,
     ATTACH_BY_VALUE, ATTACH_EMBEDDED_MSG, STGM_WRITE, STGM_TRANSACTED,
     MAPI_UNICODE, MAPI_TO, MAPI_CC, MAPI_BCC, MAPI_E_NOT_FOUND,
-    MAPI_E_NOT_ENOUGH_MEMORY, PT_SYSTIME, MAPI_ASSOCIATED,
+    MAPI_E_NOT_ENOUGH_MEMORY, MAPI_ASSOCIATED,
     WrapCompressedRTFStream, MODRECIP_ADD, MODRECIP_REMOVE,
     RELOP_EQ
 )
 
+from MAPI.Util.codepage import GetCharsetByCP
+
 from MAPI.Defs import (
     HrGetOneProp, CHANGE_PROP_TYPE
 )
@@ -63,7 +65,6 @@ from MAPI.Tags import (
     PR_MESSAGE_ATTACHMENTS, PR_RECIPIENT_TYPE, PR_ADDRTYPE_W,
     PR_EMAIL_ADDRESS_W, PR_SMTP_ADDRESS_W, PR_NULL, PR_HTML,
     PR_RTF_COMPRESSED, PR_SENDER_SEARCH_KEY,
-    PR_START_DATE, PR_END_DATE, PR_OWNER_APPT_ID, PR_RESPONSE_REQUESTED,
     PR_SENT_REPRESENTING_SEARCH_KEY, PR_ATTACHMENT_FLAGS,
     PR_ATTACHMENT_HIDDEN, PR_ATTACHMENT_LINKID, PR_ATTACH_FLAGS,
     PR_NORMALIZED_SUBJECT_W, PR_INTERNET_MESSAGE_ID_W, PR_CONVERSATION_ID,
@@ -78,7 +79,7 @@ from MAPI.Tags import (
 )
 
 from .pidlid import (
-    PidLidAppointmentStateFlags, PidLidCleanGlobalObjectId, PidLidResponseStatus,
+    PidLidAppointmentStateFlags, PidLidResponseStatus,
     PidLidAppointmentStartWhole, PidLidAppointmentEndWhole, PidLidFInvited
 )
 
@@ -91,8 +92,7 @@ from .compat import (
 
 from .defs import (
     NAMED_PROPS_ARCHIVER, NAMED_PROP_CATEGORY, ADDR_PROPS,
-    PSETID_Archive, URGENCY, REV_URGENCY, ASF_MEETING, ASF_RECEIVED,
-    ASF_CANCELED, CODEPAGE_ENCODING
+    PSETID_Archive, URGENCY, REV_URGENCY
 )
 from .errors import (
     Error, NotFoundError, _DeprecationWarning
@@ -103,6 +103,7 @@ from .properties import Properties
 from .recurrence import Occurrence
 from .restriction import Restriction
 from .meetingrequest import MeetingRequest, _copytags, _create_meetingrequest
+from .distlist import DistList
 from .address import Address
 from .table import Table
 from .contact import Contact
@@ -113,10 +114,6 @@ if sys.hexversion >= 0x03000000:
         from . import folder as _folder
     except ImportError: # pragma: no cover
         _folder = sys.modules[__package__+'.folder']
-    try:
-        from . import store as _store
-    except ImportError: # pragma: no cover
-        _store = sys.modules[__package__ + '.store']
     try:
         from . import user as _user
     except ImportError: # pragma: no cover
@@ -128,7 +125,6 @@ if sys.hexversion >= 0x03000000:
     from . import property_ as _prop
 else: # pragma: no cover
     import folder as _folder
-    import store as _store
     import user as _user
     import utils as _utils
     import property_ as _prop
@@ -160,7 +156,7 @@ class Item(Properties, Contact, Appointment):
 
     def __init__(self, folder=None, eml=None, ics=None, vcf=None, load=None,
                  loads=None, attachments=True, create=False, mapiobj=None,
-                 entryid=None, content_flag=None, cache={}, save=True):
+                 entryid=None, content_flag=None, cache={}, save=True, read=None):
         self._eml = None
         self._architem = None
         self._folder = None
@@ -192,7 +188,6 @@ class Item(Properties, Contact, Appointment):
                 # options for CreateMessage: 0 / MAPI_ASSOCIATED
                 dopt = inetmapi.delivery_options()
                 inetmapi.IMToMAPI(server.mapisession, self.folder.store.mapiobj, None, self.mapiobj, self._eml, dopt)
-                pass
             elif ics is not None:
                 icm = icalmapi.CreateICalToMapi(self.mapiobj, server.ab, False)
                 icm.ParseICal(ics, 'utf-8', 'UTC', self.user.mapiobj, 0)
@@ -219,6 +214,9 @@ class Item(Properties, Contact, Appointment):
                         self[PidLidAppointmentStateFlags] = 1
                         self[PidLidResponseStatus] = 1 # TODO move appt creation to appointment.py
                         self[PidLidFInvited] = False
+
+            if read is not None:
+                self.read = read
             if save:
                 _utils._save(self.mapiobj)
 
@@ -933,10 +931,24 @@ class Item(Properties, Contact, Appointment):
 
             pos += 4 + size
 
+    @property
+    def is_meetingrequest(self):
+        """ Is the item a meeting request """
+        return self.message_class.startswith('IPM.Schedule.Meeting.')
+
     @property
     def meetingrequest(self):
         return MeetingRequest(self)
 
+    @property
+    def is_distlist(self):
+        """ Is the item a distribution list """
+        return self.message_class == 'IPM.DistList'
+
+    @property
+    def distlist(self):
+        return DistList(self)
+
     def _addr_props(self, addr):
         if isinstance(addr, _user.User):
             pr_addrtype = 'ZARAFA'
@@ -1125,11 +1137,11 @@ class Item(Properties, Contact, Appointment):
                             raise MAPIErrorNotFound()
                         data = _utils.stream(att, PR_ATTACH_DATA_BIN)
                     except MAPIErrorNotFound:
-                        log.warn("no data found for attachment of item with entryid %s" % _main_item.entryid)
+                        log.warning("no data found for attachment of item with entryid %s", _main_item.entryid)
                         data = ''
                     atts.append(([[a, b, None] for a, b in row.items()], data))
             except Exception as e: # XXX generalize so usable in more places
-                log.error('could not serialize attachment for item with entryid %s' % _main_item.entryid)
+                log.error('could not serialize attachment for item with entryid %s', _main_item.entryid)
                 if skip_broken:
                     log.error(traceback.format_exc())
                     service = self.server.service
@@ -1327,11 +1339,6 @@ class Item(Properties, Contact, Appointment):
 
         return self.copy(folder, _delete=True)
 
-    @property
-    def is_meetingrequest(self):
-        """ Is the item a meeting request """
-        return self.message_class.startswith('IPM.Schedule.Meeting.')
-
     @property
     def codepage(self):
         """ Windows codepage """
@@ -1346,10 +1353,23 @@ class Item(Properties, Contact, Appointment):
         """ Encoding used for html body"""
         if self.codepage is not None:
             try:
-                return CODEPAGE_ENCODING[self.codepage]
-            except KeyError:
+                return GetCharsetByCP(self.codepage)
+            except Exception:
                 raise NotFoundError('no encoding for codepage: %d' % self.codepage)
 
+    @property
+    def type_(self):
+        if self.message_class is None or self.message_class.startswith('IPM.Note') or self.message_class.startswith('IPM.Schedule'):
+            return 'mail'
+        elif self.message_class == 'IPM.Appointment':
+            return 'appointment'
+        elif self.message_class == 'IPM.Contact':
+            return 'contact'
+        elif self.message_class == 'IPM.DistList':
+            return 'distlist'
+        else:
+            return 'item'
+
     def __eq__(self, i): # XXX check same store?
         if isinstance(i, Item):
             return self.entryid == i.entryid
