@@ -47,9 +47,9 @@ from MAPI.Tags import (
 
 from .errors import (
     Error, NotFoundError, DuplicateError, NotSupportedError,
-    LogonError
+    LogonError, ArgumentError
 )
-from .log import LOG
+from .log import LOG, _loglevel
 
 from .parser import parser
 from .table import Table
@@ -142,20 +142,37 @@ def instance_method_lru_cache(*cache_args, **cache_kwargs):
 #
 # https://bugs.python.org/issue9072
 #
-# this seems to cause arbitrary stuff kept in memory (referenced by these
-# modules), in our case causing non-zero reference counts on the C side,
-# finally making valgrind go nuts.
+# also, for the tests we've seen SWIG objects end up here:
 #
-# so for now we just clear all server/store internals, to try and clean up all
-# open mapi stores before final shutdown, but only in development mode, as it's
-# just a shutdown issue.
+# https://docs.python.org/2/library/gc.html#gc.garbage
 #
-# TODO investigate further; check python3
+# in both cases, store objects are not finalized, so the associated memory
+# on the C side is not released, causing valgrind to report many leaks.
+#
+# to avoid valgrind going nuts, we manually clean up references at shutdown.
+# for the second case, this may only be a work-around as it may be too late.
+#
+# for python3, both problems may have been solved already:
+#
+# https://www.python.org/dev/peps/pep-0442/
+#
+# and if not, python3 provides a work-around we could use, so manual
+# clearing can be done each collection:
+#
+# https://docs.python.org/3/library/gc.html#gc.callbacks
+#
+# of course we might also try to prevent cycles in the first place.
+#
+# TODO valgrind python3
 
 def _cleanup_mapistores():
     for obj in gc.get_objects():
         if isinstance(obj, (Server, _store.Store)):
             obj.__dict__.clear()
+        elif hasattr(obj, '__class__') and obj.__class__.__name__ in ('IMAPISession', 'IMsgStore', 'IECServiceAdmin', 'IExchangeManageStore'):
+            obj.__dict__.clear()
+
+    del gc.garbage[:]
     gc.collect()
 
 if os.getenv('ZCPSRCDIR'):
@@ -192,6 +209,9 @@ class Server(object):
             self.log = log
         elif service:
             self.log = service.log
+        elif config:
+            self.log = LOG
+            self.log.setLevel(_loglevel(options, config))
         else:
             self.log = LOG
         self.mapisession = mapisession
@@ -200,7 +220,7 @@ class Server(object):
         if not self.mapisession:
             # get cmd-line options
             if parse_args and not self.options:
-                self.options, args = parser().parse_args()
+                self.options, _ = parser().parse_args()
 
             # determine config file
             if config:
@@ -257,7 +277,7 @@ class Server(object):
                     break
                 except (MAPIErrorNetworkError, MAPIErrorDiskError):
                     if service:
-                        self.log.warn("could not connect to server at '%s', retrying in 5 sec" % self.server_socket)
+                        self.log.warning("could not connect to server at '%s', retrying in 5 sec", self.server_socket)
                         time.sleep(5)
                     else:
                         raise Error("could not connect to server at '%s'" % self.server_socket)
@@ -367,6 +387,10 @@ class Server(object):
         :param email: email address
         :param create: create user if it doesn't exist (name required)
         """
+
+        if not (name or email or userid):
+            raise ArgumentError('missing argument to identify user')
+
         try:
             return _user.User(name, email=email, server=self, userid=userid)
         except NotFoundError:
@@ -383,7 +407,8 @@ class Server(object):
             pass
 
     def users(self, remote=False, system=False, parse=True, page_start=None,
-              page_limit=None, order=None, hidden=True, inactive=True): # TODO hidden, inactive default False?
+              page_limit=None, order=None, hidden=True, inactive=True,
+              _server=None, _company=None, query=None):
         """Return all :class:`users <User>` on server.
 
         :param remote: include users on remote server nodes
@@ -391,31 +416,66 @@ class Server(object):
         """
         pos = 0
         count = 0
-        if parse and getattr(self.options, 'users', None):
-            for username in self.options.users:
+
+        multitenant = self.multitenant
+
+        # use query
+        if query is not None:
+            store = _store.Store(mapiobj=self.mapistore, server=self)
+            restriction = _query_to_restriction(query, 'user', store) # TODO use restriction to filter company!
+            columns = [PR_ENTRYID, PR_DISPLAY_NAME_W, PR_SMTP_ADDRESS_W]
+            table = self.gab_table(restriction=restriction, columns=columns)
+            for row in table.rows():
+                userid=_benc(row[0].value)
+                try:
+                    user = self.user(userid=userid)
+                except NotFoundError:
+                    self.log.warning('could not open user with userid "%s"', userid)
+                    continue
+                if multitenant and _company and _company != user.company:
+                    continue
                 if page_start is None or pos >= page_start:
-                    yield _user.User(username, self)
+                    yield user
                     count += 1
                 if page_limit is not None and count >= page_limit:
                     return
                 pos += 1
             return
-        try:
-            for name in self._companylist():
-                for user in Company(name, self).users(): # TODO filter for args?
-                    if page_start is None or pos >= page_start:
-                        yield user
-                        count += 1
-                    if page_limit is not None and count >= page_limit:
-                        return
-                    pos += 1
-        except MAPIErrorNoSupport:
-            for ecuser in self.sa.GetUserList(None, MAPI_UNICODE):
-                user = _user.User(server=self, ecuser=ecuser)
-                if ((system or user.name != u'SYSTEM') and
+
+        def include(user, ecuser):
+            return ((system or user.name != u'SYSTEM') and
                     (remote or ecuser.Servername in (self.name, '')) and
                     (hidden or not user.hidden) and
-                    (inactive or user.active)):
+                    (inactive or user.active))
+
+        # users specified on command-line
+        if parse and getattr(self.options, 'users', None):
+            for username in self.options.users:
+                yield _user.User(username, self)
+            return
+
+        # multi-tenant: get users per company
+        if multitenant:
+            if _company:
+                companies = [_company]
+            else:
+                companies = [Company(name, self) for name in self._companylist()] # TODO slow
+            for company in companies:
+                for ecuser in self.sa.GetUserList(_bdec(company.companyid), MAPI_UNICODE):
+                    user = _user.User(server=self, ecuser=ecuser)
+                    if include(user, ecuser):
+                        if page_start is None or pos >= page_start:
+                            yield user
+                            count += 1
+                        if page_limit is not None and count >= page_limit:
+                            return
+                        pos += 1
+
+        # single-tenant: get all users
+        else:
+            for ecuser in self.sa.GetUserList(None, MAPI_UNICODE):
+                user = _user.User(server=self, ecuser=ecuser)
+                if include(user, ecuser):
                     if page_start is None or pos >= page_start:
                         yield user
                         count += 1
@@ -423,14 +483,6 @@ class Server(object):
                         return
                     pos += 1
 
-    def _user_query(self, query): # TODO merge as .users('..')?
-        store = _store.Store(mapiobj=self.mapistore, server=self)
-        restriction = _query_to_restriction(query, 'user', store)
-        columns = [PR_ENTRYID, PR_DISPLAY_NAME_W, PR_SMTP_ADDRESS_W]
-        table = self.gab_table(restriction=restriction, columns=columns)
-        for row in table.rows():
-            yield self.user(userid=_benc(row[0].value))
-
     def create_user(self, name, email=None, password=None, company=None, fullname=None, create_store=True):
         """Create a new :class:`user <User>` on the server.
 
@@ -620,6 +672,8 @@ class Server(object):
         fullname = _unicode(fullname)
         try:
             self.sa.CreateGroup(ECGROUP(name, fullname, email, int(hidden), groupid), MAPI_UNICODE)
+        except MAPIErrorNoSupport:
+            raise NotSupportedError("cannot create groups with configured user plugin")
         except MAPIErrorCollision:
             raise DuplicateError("group '%s' already exists" % name)
 
