@@ -13,9 +13,9 @@ import uuid
 import sys
 
 from MAPI import (
-    MAPI_UNICODE, MAPI_MODIFY, KEEP_OPEN_READWRITE, PT_MV_BINARY,
-    RELOP_EQ, TBL_BATCH, ECSTORE_TYPE_PUBLIC, FOLDER_SEARCH,
-    MAPI_ASSOCIATED, MAPI_DEFERRED_ERRORS, ROW_REMOVE, MAPI_CREATE,
+    MAPI_UNICODE, MAPI_MODIFY, PT_MV_BINARY, RELOP_EQ,
+    TBL_BATCH, ECSTORE_TYPE_PUBLIC, FOLDER_SEARCH, MAPI_ASSOCIATED,
+    MAPI_DEFERRED_ERRORS, ROW_REMOVE, MAPI_CREATE,
 )
 from MAPI.Defs import (
     HrGetOneProp, CHANGE_PROP_TYPE, PpropFindProp
@@ -42,7 +42,7 @@ from MAPI.Tags import (
 )
 from MAPI.Struct import (
     SPropertyRestriction, SPropValue, ROWENTRY, MAPINAMEID,
-    MAPIErrorNotFound, MAPIErrorInvalidEntryid,
+    MAPIErrorNotFound, MAPIErrorInvalidEntryid, MAPIErrorNoSupport
 )
 
 from .defs import (
@@ -196,7 +196,7 @@ class Store(Properties):
         """:class:`Folder` designated as inbox."""
         try:
             return _folder.Folder(self, _benc(self.mapiobj.GetReceiveFolder(u'IPM', MAPI_UNICODE)[0]))
-        except (MAPIErrorNotFound, NotFoundError):
+        except (MAPIErrorNotFound, NotFoundError, MAPIErrorNoSupport):
             pass
 
     @inbox.setter
