@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # SPDX-License-Identifier: AGPL-3.0-only
 from .version import __version__
 
@@ -10,6 +10,7 @@ import datetime
 import fcntl
 from multiprocessing import Queue
 import os.path
+import re
 import shutil
 import sys
 import time
@@ -38,14 +39,14 @@ from MAPI.Struct import (
 )
 
 from MAPI.Tags import (
-    PR_EC_BACKUP_SOURCE_KEY, PR_EC_OUTOFOFFICE, PR_ENTRYID,
+    PR_EC_BACKUP_SOURCE_KEY, PR_EC_OUTOFOFFICE, PR_ENTRYID, PR_DISPLAY_NAME_W,
     PR_EC_OUTOFOFFICE_SUBJECT, PR_EC_OUTOFOFFICE_MSG, PR_EC_OUTOFOFFICE_FROM,
     PR_EC_OUTOFOFFICE_UNTIL, IID_IExchangeModifyTable, PR_CONTAINER_CLASS_W,
     PR_SOURCE_KEY, PR_ACL_TABLE, PR_STORE_RECORD_KEY, PR_RULES_DATA,
     PR_FREEBUSY_ENTRYIDS, PR_SCHDINFO_DELEGATE_ENTRYIDS, PT_TSTRING,
     PR_EC_WEBACCESS_SETTINGS_W, PR_EC_RECIPIENT_HISTORY_W,
     PR_EC_WEBACCESS_SETTINGS_JSON_W, PR_EC_RECIPIENT_HISTORY_JSON_W,
-    PR_EC_WEBAPP_PERSISTENT_SETTINGS_JSON_W
+    PR_EC_WEBAPP_PERSISTENT_SETTINGS_JSON_W, PR_STORE_ENTRYID
 )
 
 WEBAPP_SETTINGS = (
@@ -54,6 +55,8 @@ WEBAPP_SETTINGS = (
     PR_EC_WEBAPP_PERSISTENT_SETTINGS_JSON_W,
 )
 
+UNESCAPED_SLASH_RE = re.compile(r'(?<!\\)/')
+
 import kopano
 from kopano import log_exc, Config
 
@@ -328,6 +331,7 @@ class FolderImporter:
 
     def __init__(self, *args):
         self.folder, self.folder_path, self.config, self.options, self.log, self.stats, self.service = args
+        self.store = self.folder.store
         self.reset_cache()
 
     def reset_cache(self):
@@ -344,15 +348,7 @@ class FolderImporter:
             data = zlib.compress(item.dumps(attachments=not self.options.skip_attachments, archiver=False, skip_broken=True))
             self.item_updates.append((item.sourcekey, data))
 
-            orig_prop = item.get_prop(PR_EC_BACKUP_SOURCE_KEY)
-            if orig_prop:
-                orig_prop = _hex(orig_prop.value)
-            idx = pickle_dumps({
-                b'subject': item.subject,
-                b'orig_sourcekey': orig_prop,
-                b'last_modified': item.last_modified,
-                b'backup_updated': self.service.timestamp,
-            })
+            idx = self.make_idx(item, item.read)
             self.index_updates.append((item.sourcekey, idx))
 
             self.stats['changes'] += 1
@@ -361,6 +357,19 @@ class FolderImporter:
             if self.cache_size > CACHE_SIZE:
                 self.commit()
 
+    def make_idx(self, item, read):
+        orig_prop = item.get_prop(PR_EC_BACKUP_SOURCE_KEY)
+        if orig_prop:
+            orig_prop = _hex(orig_prop.value)
+        idx = pickle_dumps({
+            b'subject': item.subject,
+            b'orig_sourcekey': orig_prop,
+            b'last_modified': item.last_modified,
+            b'backup_updated': self.service.timestamp,
+            b'read': read,
+        })
+        return idx
+
     def delete(self, item, flags): # XXX batch as well, 'updating' cache?
         """ deleted item from 'items' and 'index' databases """
 
@@ -383,6 +392,10 @@ class FolderImporter:
                 })
             self.stats['deletes'] += 1
 
+    def read(self, item, state):
+        idx = self.make_idx(item, state)
+        self.index_updates.append((item.sourcekey, idx))
+
     def commit(self):
         """ commit data to storage """
 
@@ -442,6 +455,9 @@ class Service(kopano.Service):
     def restore(self, data_path):
         """ restore data from backup """
 
+        self.restored_sourcekeys = set()
+        self.options.sourcekeys = [sk.upper() for sk in self.options.sourcekeys]
+
         # determine store to restore to
         self.log.info('starting restore of %s', data_path)
         username = os.path.split(data_path)[1]
@@ -475,12 +491,28 @@ class Service(kopano.Service):
         t0 = time.time()
         stats = {'changes': 0, 'errors': 0}
 
+        # determine restore root
+        if self.options.restore_root:
+            restore_root = store.folder(_decode(self.options.restore_root), create=True)
+        else:
+            restore_root = store.subtree
+
+        # check existing folders
+        sk_folder = {}
+        for folder in restore_root.folders():
+            orig_sk = folder.get(PR_EC_BACKUP_SOURCE_KEY)
+            if orig_sk:
+                sk_folder[orig_sk] = folder
+
         # restore specified (parts of) folders
-        restored = []
+        meta_folders = []
+        sks = set()
         for path in paths:
             fpath = path_folder[path]
-            restore_path = _decode(self.options.restore_root)+'/'+path if self.options.restore_root else path
+            folderprops = pickle_loads(open('%s/folder' % fpath, 'rb').read())
+            folder_sk = folderprops[PR_SOURCE_KEY]
 
+            # determine folder to restore
             if self.options.sourcekeys:
                 with closing(dbopen(fpath+'/items')) as db:
                     if not [sk for sk in self.options.sourcekeys if sk.encode('ascii') in db]:
@@ -489,21 +521,51 @@ class Service(kopano.Service):
                 if self.options.deletes in (None, 'no') and folder_deleted(fpath):
                     continue
 
-                folder = store.subtree.get_folder(restore_path)
+                sks.add(folder_sk)
+
+                folder = restore_root.get_folder(path)
                 if (folder and not store.public and \
                     ((self.options.skip_junk and folder == store.junk) or \
                     (self.options.skip_deleted and folder == store.wastebasket))):
                         continue
 
-            if not self.options.only_meta:
-                folder = store.subtree.folder(restore_path, create=True)
+            # restore folder
+            if self.options.only_meta: # TODO create empty folders with acls/rules, or skip non-existing folders?
+                folder = restore_root.get_folder(path)
+            else:
+                # differential folder move
+                folder = sk_folder.get(folder_sk)
+                if folder and self.options.differential:
+                    restore_path = self.options.restore_root+'/'+path if self.options.restore_root else path
+                    restore_parent_path = '/'.join(UNESCAPED_SLASH_RE.split(restore_path)[:-1])
+                    if folder.parent.path != restore_parent_path:
+                        newparent = store.get_folder(restore_parent_path)
+                        if newparent:
+                            self.log.info('moving folder %s to %s', folder.path, restore_path)
+                            folder.parent.move(folder, newparent)
+                else:
+                    folder = restore_root.folder(path, create=True)
+
+                if self.options.clean_folders:
+                    self.log.info('emptying folder %s', folder.path)
+                    folder.empty()
                 self.restore_folder(folder, path, fpath, store, store.subtree, stats, user, self.server)
-            restored.append((folder, fpath))
+            if folder:
+                meta_folders.append((folder, fpath))
+
+        # differential folder deletes
+        if self.options.differential:
+            for sk in set(sk_folder)-sks:
+                path = sk_folder[sk].path
+                parent = store.get_folder('/'.join(UNESCAPED_SLASH_RE.split(path)[:-1]))
+                if parent:
+                    self.log.info('deleting folder %s', path)
+                    parent.delete(sk_folder[sk])
 
         # restore folder-level metadata
         if not (self.options.sourcekeys or self.options.skip_meta):
             self.log.info('restoring metadata')
-            for (folder, fpath) in restored:
+            for (folder, fpath) in meta_folders:
                 load_acl(folder, user, self.server, open(fpath+'/acl', 'rb').read(), stats, self.log)
                 load_rules(folder, user, self.server, open(fpath+'/rules', 'rb').read(), stats, self.log)
 
@@ -525,6 +587,10 @@ class Service(kopano.Service):
             if os.path.exists('%s/acl' % data_path):
                 load_acl(store, user, self.server, open('%s/acl' % data_path, 'rb').read(), stats, self.log)
 
+        for sourcekey in self.options.sourcekeys:
+            if sourcekey not in self.restored_sourcekeys:
+                self.log.error('could not restore sourcekey: %s', sourcekey)
+
         self.log.info('restore completed in %.2f seconds (%d changes, ~%.2f/sec, %d errors)',
             time.time()-t0, stats['changes'], stats['changes']/(time.time()-t0), stats['errors'])
 
@@ -667,16 +733,18 @@ class Service(kopano.Service):
         return [(job[0].entryid,)+job[1:] for job in sorted(jobs, reverse=True, key=lambda x: x[0].size)]
 
     def restore_folder(self, folder, path, data_path, store, subtree, stats, user, server):
-        """ restore single folder (or potential item in folder) """
+        """ restore (partial) folder """
+
+        folderprops = pickle_loads(open('%s/folder' % data_path, 'rb').read())
 
         if not self.options.sourcekeys:
             self.log.debug('restoring folder %s', path)
 
-            # restore container class
-            folderprops = pickle_loads(open('%s/folder' % data_path, 'rb').read())
-            container_class = folderprops.get(PR_CONTAINER_CLASS_W)
-            if container_class:
-                folder.container_class = container_class
+            # restore name, container class
+            for proptag in (PR_DISPLAY_NAME_W, PR_CONTAINER_CLASS_W):
+                value = folderprops.get(proptag)
+                if value is not None:
+                    folder[proptag] = value
 
         # load existing sourcekeys in folder, to check for duplicates
         existing = {}
@@ -734,22 +802,44 @@ class Service(kopano.Service):
                     ):
                          continue
 
+                    # handle existing item
+                    entryid = existing.get(sourcekey2a) or existing.get(index[sourcekey2a][b'orig_sourcekey'])
+                    if entryid is not None:
+                        if self.options.differential or self.options.overwrite:
+                            folder.delete(folder.item(entryid=entryid))
+                        else:
+                            self.log.warning('skipping duplicate item with sourcekey %s', sourcekey2)
+                            continue
+
                     # restore item
-                    if sourcekey2a in existing or index[sourcekey2a][b'orig_sourcekey'] in existing:
-                        self.log.warning('skipping duplicate item with sourcekey %s', sourcekey2)
-                    else:
-                        self.log.debug('restoring item with sourcekey %s', sourcekey2)
-                        data = zlib.decompress(db_items[sourcekey2a])
-                        item = folder.create_item(loads=data, attachments=not self.options.skip_attachments)
+                    self.log.debug('restoring item with sourcekey %s', sourcekey2)
+                    data = zlib.decompress(db_items[sourcekey2a])
+                    read = index[sourcekey2a].get(b'read')
 
-                        # store original sourcekey or it is lost
-                        try:
-                            item.prop(PR_EC_BACKUP_SOURCE_KEY)
-                        except (MAPIErrorNotFound, kopano.NotFoundError):
-                            item.mapiobj.SetProps([SPropValue(PR_EC_BACKUP_SOURCE_KEY, _unhex(sourcekey2))])
-                            item.mapiobj.SaveChanges(0)
+                    item = folder.create_item(
+                        loads=data,
+                        attachments=not self.options.skip_attachments,
+                        read=read,
+                    )
 
-                        stats['changes'] += 1
+                    # store original item sourcekey or it is lost
+                    try:
+                        item.prop(PR_EC_BACKUP_SOURCE_KEY)
+                    except (MAPIErrorNotFound, kopano.NotFoundError):
+                        item.mapiobj.SetProps([SPropValue(PR_EC_BACKUP_SOURCE_KEY, _unhex(sourcekey2))])
+                        item.mapiobj.SaveChanges(0)
+
+                    if self.options.sourcekeys:
+                        self.restored_sourcekeys.add(sourcekey2)
+                    stats['changes'] += 1
+
+        # store original folder sourcekey
+        folder_sk = folderprops[PR_SOURCE_KEY]
+        try:
+            folder.prop(PR_EC_BACKUP_SOURCE_KEY)
+        except (MAPIErrorNotFound, kopano.NotFoundError):
+            folder.mapiobj.SetProps([SPropValue(PR_EC_BACKUP_SOURCE_KEY, folder_sk)])
+            folder.mapiobj.SaveChanges(0)
 
     def _store(self, username):
         """ lookup store for username """
@@ -910,8 +1000,8 @@ def dump_rules(folder, user, server, stats, log):
                     try:
                         s = movecopy.findall('store')[0]
                         store = server.mapisession.OpenMsgStore(0, _unbase64(s.text), None, 0)
-                        guid = _hex(HrGetOneProp(store, PR_STORE_RECORD_KEY).Value)
-                        store = server.store(guid) # XXX guid doesn't work for multiserver?
+                        entryid = _hex(HrGetOneProp(store, PR_STORE_ENTRYID).Value)
+                        store = server.store(entryid=entryid)
                         if store.public:
                             s.text = 'public'
                         else:
@@ -919,8 +1009,8 @@ def dump_rules(folder, user, server, stats, log):
                         f = movecopy.findall('folder')[0]
                         path = store.folder(entryid=_hex(_unbase64(f.text))).path
                         f.text = path
-                    except (MAPIErrorNotFound, kopano.NotFoundError, binascii.Error):
-                        log.warning("cannot serialize rule for unknown store/folder")
+                    except Exception as e:
+                        log.warning("could not resolve rule target: %s", str(e))
             ruledata = ElementTree.tostring(etxml)
     return pickle_dumps(ruledata)
 
@@ -942,8 +1032,8 @@ def load_rules(folder, user, server, data, stats, log):
                         s.text = _base64(_unhex(store.entryid))
                         f = movecopy.findall('folder')[0]
                         f.text = _base64(_unhex(store.folder(f.text).entryid))
-                    except kopano.NotFoundError:
-                        log.warning("skipping rule for unknown store/folder")
+                    except Exception as e:
+                        log.warning("could not resolve rule target: %s", str(e))
             etxml = ElementTree.tostring(etxml)
             folder.create_prop(PR_RULES_DATA, etxml)
 
@@ -991,10 +1081,12 @@ def main():
     parser.add_option('', '--restore-root', dest='restore_root', help='restore under specific folder', metavar='PATH')
     parser.add_option('', '--stats', dest='stats', action='store_true', help='list folders for PATH')
     parser.add_option('', '--index', dest='index', action='store_true', help='list items for PATH')
-    parser.add_option('', '--sourcekey', dest='sourcekeys', action='append', help='restore specific sourcekey', metavar='SOURCEKEY')
+    parser.add_option('', '--sourcekey', dest='sourcekeys', action='append', default=[], help='restore specific sourcekey', metavar='SOURCEKEY')
     parser.add_option('', '--recursive', dest='recursive', action='store_true', help='backup/restore folders recursively')
     parser.add_option('', '--differential', dest='differential', action='store_true', help='create/restore differential backup')
+    parser.add_option('', '--overwrite', dest='overwrite', action='store_true', help='overwrite duplicate items')
     parser.add_option('', '--merge', dest='merge', action='store_true', help='merge differential backups')
+    parser.add_option('', '--clean-folders', dest='clean_folders', action='store_true', help='empty folder(s) before restore (dangerous!)')
 
     # parse and check command-line options
     options, args = parser.parse_args()
@@ -1011,6 +1103,8 @@ def main():
         fatal('invalid use of --folder option')
     if options.output_dir and options.differential:
         fatal('invalid use of --output-dir option')
+    if options.sourcekeys and options.differential:
+        fatal('invalid use of --sourcekeys option')
 
     if options.stats or options.index:
         # handle --stats/--index
