@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # SPDX-License-Identifier: AGPL-3.0-only
 from .version import __version__
 
@@ -21,7 +21,7 @@ from flask import Flask, request, abort
 CONFIG = {
     'data_path': Config.string(default='/var/db/kopano/presence/'),
     'data_save_interval': Config.integer(default=5),
-    'plugins': Config.string(multiple=True, default="spreed"),
+    'plugins': Config.string(multiple=True, default=['spreed']),
     'run_as_user': Config.string(default="_kopano"),
     'run_as_group': Config.string(default="_kopano"),
     'server_bind': Config.string(default="127.0.0.1"),
@@ -66,7 +66,7 @@ class Service(kopano.Service):
         sys.exit(0)
 
     def check_auth(self):
-        """ check shared-secret based authentication token """ 
+        """ check shared-secret based authentication token """
 
         secret_key = str(self.config['server_secret_key'])
         t, userid, sha256 = str(request.json['AuthenticationToken']).split(':')
@@ -131,7 +131,7 @@ class Service(kopano.Service):
     def data_set(self, username, plugin, status, message):
         """ atomic update of user data """
 
-        self.log.debug('%s: %s %s' % (plugin, username, status))
+        self.log.debug('%s: %s %s', plugin, username, status)
         with self.lock:
             userplugin = self.data.setdefault(username, {}).setdefault(plugin, {})
             userplugin['status'] = status
@@ -141,6 +141,6 @@ def main():
     parser = kopano.parser('ckpsF')
     options, args = parser.parse_args()
     Service('presence', config=CONFIG, options=options).start()
-    
+
 if __name__ == '__main__':
     main()
